@@ -5,6 +5,11 @@ if __name__=="__main__":
     # check if current git work tree is clean and has no untracked files
     # if yes, checkout to release branch else exit
     if not os.system("git diff --quiet && git diff --cached --quiet"):
+        # if release and dev on the same commit, exit
+        if os.system("git rev-parse --abbrev-ref HEAD") == "release":
+            print("release branch is on the same commit as dev branch, exit")
+            exit(1)
+
         # checkout to release branch
         os.system("git checkout release")
         # merge dev branch to release branch
